@@ -35,7 +35,7 @@ class Authentication:
         logout_api = 'auth.cgi?api=SYNO.API.Auth'
         param = {'version': '2', 'method': 'logout', 'session': application}
 
-        response = requests.get(self._base_url + logout_api, param)
+        response = requests.get(self._base_url + logout_api, param, verify=self._verify)
         if response.json()['success'] is True:
             self._session_expire = True
             self._sid = None
