@@ -11,9 +11,9 @@ from . import auth as syn
 
 class FileStation:
 
-    def __init__(self, ip_address, port, username, password, secure=False):
+    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False):
 
-        self.session = syn.Authentication(ip_address, port, username, password, secure)
+        self.session = syn.Authentication(ip_address, port, username, password, secure, cert_verify)
 
         self._dir_taskid = ''
         self._dir_taskid_list = []
